@@ -9,10 +9,13 @@ class Manifest:
     # name of the Fatman Workload
     name: str
 
+    # email address of the Fatman's owner to reach out
+    owner_email: str
+
     git: 'GitManifest'
 
-    # version of the Manifest file
-    version: str = '1'
+    # version of the Fatman
+    version: str = '0.0.1'
 
     # Language wrapper used to embed model
     lang: str = 'python3'
