@@ -1,4 +1,5 @@
 import logging
+import re
 from pathlib import Path
 
 from racetrack_client.log.context_error import wrap_context
@@ -33,3 +34,4 @@ def validate_manifest(manifest: Manifest):
         assert manifest.golang is None, f'"golang" configuration should be filled only for golang jobs'
     if manifest.lang != 'docker-http':
         assert manifest.docker is None, f'"docker" configuration should be filled only for docker-http jobs'
+    assert re.match(r"[^@]+@[^@]+\.[^@]+", manifest.owner_email), '"owner_email" is not a valid email'
