@@ -23,7 +23,7 @@ def load_config(clazz: Type[T], cast_types: List[Type] = None) -> T:
 
     path = Path(config_file_path)
     if not path.is_file():
-        raise FileNotFoundError(f'config file {config_file_path} doesnt exist')
+        raise FileNotFoundError(f"config file {config_file_path} doesn't exist")
 
     try:
         with path.open() as file:
